==> allure-model-1.4.23-sources.jar: ru/yandex/qatools/allure/model/LabelName.java <==

package ru.yandex.qatools.allure.model;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for label-name.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="label-name">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="feature"/>
 *     &lt;enumeration value="story"/>
 *     &lt;enumeration value="severity"/>
 *     &lt;enumeration value="language"/>
 *     &lt;enumeration value="framework"/>
 *     &lt;enumeration value="issue"/>
 *     &lt;enumeration value="testId"/>
 *     &lt;enumeration value="host"/>
 *     &lt;enumeration value="thread"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "label-name")
@XmlEnum
public enum LabelName {

    @XmlEnumValue("feature")
    FEATURE("feature"),
    @XmlEnumValue("story")
    STORY("story"),
    @XmlEnumValue("severity")
    SEVERITY("severity"),
    @XmlEnumValue("language")
    LANGUAGE("language"),
    @XmlEnumValue("framework")
    FRAMEWORK("framework"),
    @XmlEnumValue("issue")
    ISSUE("issue"),
    @XmlEnumValue("testId")
    TEST_ID("testId"),
    @XmlEnumValue("host")
    HOST("host"),
    @XmlEnumValue("thread")
    THREAD("thread");
    private final String value;

    LabelName(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static LabelName fromValue(String v) {
        for (LabelName c: LabelName.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> allure-model-1.5.4-sources.jar: ru/yandex/qatools/allure/model/LabelName.java <==

package ru.yandex.qatools.allure.model;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for label-name.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="label-name">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="feature"/>
 *     &lt;enumeration value="story"/>
 *     &lt;enumeration value="severity"/>
 *     &lt;enumeration value="language"/>
 *     &lt;enumeration value="framework"/>
 *     &lt;enumeration value="issue"/>
 *     &lt;enumeration value="testId"/>
 *     &lt;enumeration value="host"/>
 *     &lt;enumeration value="thread"/>
 *     &lt;enumeration value="testSuite"/>
 *     &lt;enumeration value="testGroup"/>
 *     &lt;enumeration value="testClass"/>
 *     &lt;enumeration value="testMethod"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "label-name")
@XmlEnum
public enum LabelName {

    @XmlEnumValue("feature")
    FEATURE("feature"),
    @XmlEnumValue("story")
    STORY("story"),
    @XmlEnumValue("severity")
    SEVERITY("severity"),
    @XmlEnumValue("language")
    LANGUAGE("language"),
    @XmlEnumValue("framework")
    FRAMEWORK("framework"),
    @XmlEnumValue("issue")
    ISSUE("issue"),
    @XmlEnumValue("testId")
    TEST_ID("testId"),
    @XmlEnumValue("host")
    HOST("host"),
    @XmlEnumValue("thread")
    THREAD("thread"),
    @XmlEnumValue("testSuite")
    TEST_SUITE("testSuite"),
    @XmlEnumValue("testGroup")
    TEST_GROUP("testGroup"),
    @XmlEnumValue("testClass")
    TEST_CLASS("testClass"),
    @XmlEnumValue("testMethod")
    TEST_METHOD("testMethod");
    private final String value;

    LabelName(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static LabelName fromValue(String v) {
        for (LabelName c: LabelName.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
